/*
 * MZViewer - A viewer for MZData format Mass Spectra
 * Copyright (c) 2005 Simon Andrews

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */
package uk.ac.bbsrc.babraham.mzdata.displays;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;

import uk.ac.bbsrc.babraham.mzdata.MZCollection;

/**
 * @author Andrewss
 *
 */
public class ChromatogramDisplay extends JPanel {
	
	private ChromatogramDisplayPanel chromatogramDisplay;
	private JComboBox msLevelSelector;
	private JComboBox displayTypeSelector;
	
	public ChromatogramDisplay (MZCollection collection) {
		chromatogramDisplay = new ChromatogramDisplayPanel(collection);
		JPanel buttonPanel = new JPanel();
		buttonPanel.setBackground(Color.WHITE);
		
		int [] msLevels = collection.getMSLevels();
		Integer [] msLevelOptions = new Integer[msLevels.length];
		for (int i=0;i<msLevels.length;i++) {
			msLevelOptions[i] = new Integer(msLevels[i]);
		}
		
		SelectionListener l = new SelectionListener(this);

		buttonPanel.add(new JLabel("msLevel"));
		msLevelSelector = new JComboBox(msLevelOptions);
		msLevelSelector.addActionListener(l);
		buttonPanel.add(msLevelSelector);


		buttonPanel.add(new JLabel("  Display Type"));
		String [] typeOptions = new String [] {"TIC","Base Peak"}; 
		displayTypeSelector = new JComboBox(typeOptions);
		displayTypeSelector.addActionListener(l);
		buttonPanel.add(displayTypeSelector);

		
		setLayout(new BorderLayout());
		add(buttonPanel,BorderLayout.NORTH);
		add(chromatogramDisplay,BorderLayout.CENTER);
	}
	
	public void addSpectrumSelectionListener (SpectrumSelectionListener listener) {
		chromatogramDisplay.addSpectrumSelectionListener(listener);
	}

	
	private class SelectionListener implements ActionListener {
		Component c;
		public SelectionListener (Component c) {
			this.c = c;
		}

		public void actionPerformed(ActionEvent ae) {
			if (ae.getSource() == displayTypeSelector) {
				String type = (String)displayTypeSelector.getSelectedItem();
				if (type.equals("TIC")) {
					chromatogramDisplay.useBasePeakPlot(false);
				}
				else {
                    chromatogramDisplay.useBasePeakPlot(true);
				}
			}
			else if (ae.getSource() == msLevelSelector) {
				chromatogramDisplay.setMSLevel(((Integer)msLevelSelector.getSelectedItem()).intValue());
			}
		}
	}
}
