/*
 * MZViewer - A viewer for MZData format Mass Spectra
 * Copyright (c) 2005 Simon Andrews

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */
package uk.ac.bbsrc.babraham.mzdata.displays;

import java.awt.BorderLayout;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.print.PageFormat;
import java.awt.print.Printable;
import java.awt.print.PrinterException;

import javax.swing.*;

import uk.ac.bbsrc.babraham.mzdata.MZCollection;
import uk.ac.bbsrc.babraham.mzdata.MZSpectrum;

/**
 * @author Andrewss
 *
 */
public class GenericMSDisplay extends JPanel implements Printable{

	MZCollection collection;
	
	public GenericMSDisplay (MZCollection collection) {
		this.collection = collection;
		
		setLayout(new BorderLayout());

        // We use a two-panel chromatogram display if there are any
        // msLevels which can be used for this purpose
		if (collection.getMSLevels().length == 0) {
			add(new SingleSpectrumDisplay(new MZSpectrum [] {collection.getSpectrumAt(0)}),BorderLayout.CENTER);
		}
		
		else {
			JSplitPane splitPane = new JSplitPane(JSplitPane.VERTICAL_SPLIT);
			ChromatogramDisplay chromatogram = new ChromatogramDisplay(collection);
			SingleSpectrumDisplay spectrum = new SingleSpectrumDisplay();
			chromatogram.addSpectrumSelectionListener(spectrum);
			splitPane.setTopComponent(chromatogram);
			splitPane.setBottomComponent(spectrum);
			splitPane.setDividerLocation(320);
			add(splitPane,BorderLayout.CENTER);
		}
		
	}


    public int print(Graphics g, PageFormat page, int pageNo) throws PrinterException {
        if (pageNo > 0) {
            // We always scale spectra down so they fit on one page
            return Printable.NO_SUCH_PAGE;
        }
        else {
            Graphics2D g2 = (Graphics2D)g;
            //Translate the whole thing so that the borders are taken into account
            g2.translate(page.getImageableX(),page.getImageableY());

            // Scale everything down so the width of the component matches the width of the page.
            double scale = page.getImageableWidth()/this.getWidth();
            g2.scale(scale,scale);
            print(g2);
            return Printable.PAGE_EXISTS;
        }
    }
	
}
